--- loncom/interface/londocs.pm 2002/08/21 17:18:08 1.9
+++ loncom/interface/londocs.pm 2003/08/05 12:47:21 1.71
@@ -1,7 +1,7 @@
# The LearningOnline Network
# Documents
#
-# $Id: londocs.pm,v 1.9 2002/08/21 17:18:08 www Exp $
+# $Id: londocs.pm,v 1.71 2003/08/05 12:47:21 www Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -29,16 +29,30 @@
package Apache::londocs;
use strict;
-use Apache::Constants qw(:common);
+use Apache::Constants qw(:common :http);
use Apache::lonnet;
use Apache::loncommon;
use Apache::lonratedt;
use Apache::lonratsrv;
+use Apache::lonxml;
+use HTML::Entities;
+use GDBM_File;
my $iconpath;
+my %hash;
+
+my $hashtied;
+my %alreadyseen=();
+
+my $hadchanges;
+
+# Available help topics
+
+my %help=();
+
# Mapread read maps into lonratedt::global arrays
# @links and @resources, determines status
# sets @order - pointer to resources in right order
# sets @resources - array with the resources with correct idx
#
@@ -52,59 +66,308 @@ sub mapread {
sub storemap {
my ($coursenum,$coursedom,$map)=@_;
+ $hadchanges=1;
return
&Apache::lonratedt::storemap('/uploaded/'.$coursedom.'/'.$coursenum.'/'.
- $map);
+ $map,1);
}
sub editor {
my ($r,$coursenum,$coursedom,$folder,$allowed)=@_;
- my ($errtext,$fatal)=
+ if ($ENV{'form.foldername'}) {
+ $r->print('
Folder: '.$ENV{'form.foldername'}.'
');
+ }
+ my $errtext='';
+ my $fatal=0;
+ ($errtext,$fatal)=
&mapread($coursenum,$coursedom,$folder.'.sequence');
+ if ($#Apache::lonratedt::order<1) {
+ $Apache::lonratedt::order[0]=1;
+ $Apache::lonratedt::resources[1]='';
+ }
if ($fatal) {
$r->print('
'.$errtext.'
');
} else {
# ------------------------------------------------------------ Process commands
- if ($allowed) {
+# ---------------- if they are for this folder and user allowed to make changes
+ if (($allowed) && ($ENV{'form.folder'} eq $folder)) {
+# upload a file, if present
+ if (($ENV{'form.uploaddoc.filename'}) &&
+ ($ENV{'form.cmd'}=~/^upload_(\w+)/)) {
+ if ($folder=~/^$1/) {
+# this is for a course, not a user, so set coursedoc flag
+# probably the only place in the system where this should be "1"
+ my $url=&Apache::lonnet::userfileupload('uploaddoc',1);
+ my $ext='false';
+ if ($url=~/^http\:\/\//) { $ext='true'; }
+ $url=~s/\:/\:/g;
+ my $comment=$ENV{'form.comment'};
+ $comment=~s/\\<\;/g;
+ $comment=~s/\>/\>\;/g;
+ $comment=~s/\:/\:/g;
+ if ($folder=~/^supplemental/) {
+ $comment=time.'___&&&___'.$ENV{'user.name'}.'___&&&___'.
+ $ENV{'user.domain'}.'___&&&___'.$comment;
+ }
+ my $newidx=$#Apache::lonratedt::resources+1;
+ $Apache::lonratedt::resources[$newidx]=
+ $comment.':'.$url.':'.$ext.':normal:res';
+ $Apache::lonratedt::order[$#Apache::lonratedt::order+1]=
+ $newidx;
+ &storemap($coursenum,$coursedom,$folder.'.sequence');
+ }
+ }
if ($ENV{'form.cmd'}) {
-
+ my ($cmd,$idx)=split(/\_/,$ENV{'form.cmd'});
+ if ($cmd eq 'del') {
+ for (my $i=$idx;$i<$#Apache::lonratedt::order;$i++) {
+ $Apache::lonratedt::order[$i]=
+ $Apache::lonratedt::order[$i+1];
+ }
+ $#Apache::lonratedt::order--;
+ } elsif ($cmd eq 'up') {
+ if (($idx) && (defined($Apache::lonratedt::order[$idx-1]))) {
+ my $i=$Apache::lonratedt::order[$idx-1];
+ $Apache::lonratedt::order[$idx-1]=
+ $Apache::lonratedt::order[$idx];
+ $Apache::lonratedt::order[$idx]=$i;
+ }
+ } elsif ($cmd eq 'down') {
+ if (defined($Apache::lonratedt::order[$idx+1])) {
+ my $i=$Apache::lonratedt::order[$idx+1];
+ $Apache::lonratedt::order[$idx+1]=
+ $Apache::lonratedt::order[$idx];
+ $Apache::lonratedt::order[$idx]=$i;
+ }
+ } elsif ($cmd eq 'rename') {
+ my ($rtitle,@rrest)=split(/\:/,
+ $Apache::lonratedt::resources[
+ $Apache::lonratedt::order[$idx]]);
+ my $comment=
+ &HTML::Entities::decode($ENV{'form.title'});
+ $comment=~s/\\<\;/g;
+ $comment=~s/\>/\>\;/g;
+ $comment=~s/\:/\:/g;
+ $Apache::lonratedt::resources[
+ $Apache::lonratedt::order[$idx]]=
+ $comment.':'.join(':',@rrest);
+
+ }
+# Store the changed version
+ &storemap($coursenum,$coursedom,$folder.'.sequence');
}
- }
+# Group import/search
+ if ($ENV{'form.importdetail'}) {
+ foreach (split(/\&/,$ENV{'form.importdetail'})) {
+ if (defined($_)) {
+ my ($name,$url)=split(/\=/,$_);
+ $name=&Apache::lonnet::unescape($name);
+ $url=&Apache::lonnet::unescape($url);
+ if ($url) {
+ my $idx=$#Apache::lonratedt::resources+1;
+ $Apache::lonratedt::order
+ [$#Apache::lonratedt::order+1]=$idx;
+ my $ext='false';
+ if ($url=~/^http\:\/\//) { $ext='true'; }
+ $url=~s/\:/\:/g;
+ $name=~s/\:/\:/g;
+ $Apache::lonratedt::resources[$idx]=
+ $name.':'.$url.':'.$ext.':normal:res';
+ }
+ }
+ }
+# Store the changed version
+ &storemap($coursenum,$coursedom,$folder.'.sequence');
+ }
+# Loading a complete map
+ if (($ENV{'form.importmap'}) && ($ENV{'form.loadmap'})) {
+ foreach
+(&Apache::lonsequence::attemptread(&Apache::lonnet::filelocation('',$ENV{'form.importmap'}))) {
+ my $idx=$#Apache::lonratedt::resources;
+ $idx++;
+ $Apache::lonratedt::resources[$idx]=$_;
+ $Apache::lonratedt::order
+ [$#Apache::lonratedt::order+1]=$idx;
+ }
+
+# Store the changed version
+ &storemap($coursenum,$coursedom,$folder.'.sequence');
+ }
+ }
+# ---------------------------------------------------------------- End commands
# ---------------------------------------------------------------- Print screen
+ my $idx=0;
+ $r->print('
@@ -29,16 +29,30 @@
# Mapread read maps into lonratedt::global arrays
-# @links and @resources, determines status
+# @order and @resources, determines status
# sets @order - pointer to resources in right order
# sets @resources - array with the resources with correct idx